# Organizer cli
A script that scans throught the current directory and organizes all loose files into neat folders by file extension

## Dependencies
[click](https://pypi.org/project/click8/)
[colorama](https://pypi.org/project/colorama/)
[progress](https://pypi.org/project/progress/)

## Installation
```python
pip install organizer-cli
```

## Commands

* safe
* all
* image
* audio
* video
* office
* vector
* gif
* photoshop
* pdf
* font
* code
* safe
* all


## Usage 
```text
>> Organize               # Organizes all user friendly files
```
```text
>> Organize image         # Organizes all image files
```
```text
>> Organize video         # Organizes all video files
```
```text
>> Organize audio         # Organizes all audio files
```
```text
>> Organize office        # Organizes all office files
```
```text
>> Organize vector        # Organizes all vector files
```
```text
>> Organize gif           # Organizes all gif files
```
```text
>> Organize photoshop     # Organizes all photoshop files
```
```text
>> Organize pdf           # Organizes all pdf files
```
```text
>> Organize font          # Organizes all font files
```
```text
>> Organize code          # Organizes all programming files
```
```text
>> Organize safe          # Organizes all user friendly files
```
```text
>> Organize all           # Organizes all supported files
```
